@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from mkr.core.mk import MicroKernel
-from mkr.core.mkp import MicroKernelPluginManager
+from mkr.core.mkp import MKPluginManager
 
 """
 example1:
