@@ -38,10 +38,11 @@ class MKPlug:
         目标已经作为mod被成功加载，处于随时可用状态
 
     """
-    def __init__(self, mkpm, mpath:str):
+    def __init__(self, mkpm, mpath:str, encoding:str='utf-8'):
         self.code = None
         self.mkpm = mkpm
         self.packos = mkpm.packos
+        self.encoding = encoding
 
         assert os.path.isdir(mpath), "dir expected, but got " + mpath
         self._raw_path = mpath  # mod path
@@ -89,7 +90,7 @@ class MKPlug:
             self.hashid = self.packos.hash(self._raw_path)
             rmflag = False
             if self.mkpm.hash.get(self.mname):
-                print(self.hashid == self.mkpm.hash[self.mname] and os.path.exists(self.path), self.path)
+                # print(self.hashid == self.mkpm.hash[self.mname] and os.path.exists(self.path), self.path)
                 if self.hashid == self.mkpm.hash[self.mname] and os.path.exists(self.path):
                     self.state = STATE_RSTRUCT
                     self.instantiate()
@@ -100,7 +101,7 @@ class MKPlug:
             try:
                 if rmflag:
                     self.packos.remove(self.path)
-                self.packos.copy(self._raw_path, self.path)
+                self.packos.specificCopy(self._raw_path, self.path, '.py')
                 self.state = STATE_RBUF
             except Exception as err:
                 print(f"{self}:\n\tException in {self.state.__name__}: {err}")
@@ -116,7 +117,7 @@ class MKPlug:
         if self.state is STATE_READY: return True
         if self.state is STATE_RBUF:
             # 将mod_path移动到new_mod_path所需进行的pyrestruct
-            PyRestruct(self._raw_path, self.path, )
+            PyRestruct(self._raw_path, self.path, encoding=self.encoding)
             self.state = STATE_RSTRUCT
         else:
             print(f"{self} unable to restruct, due to it's unsuitable state: " + self.state.__name__)
@@ -149,8 +150,9 @@ class MKPluginManager():
     MKBUFNAME = 'mktemp'
     MKHASHNAME = 'mkphash'
     MKINFONAME = 'mkpinfo'
-    def __init__(self, target_abspath:str):
+    def __init__(self, target_abspath:str, encoding:str='utf-8'):
         self.path = target_abspath  # 目标目录，指mk项目的位置
+        self.encoding = encoding
         assert os.path.isdir(self.path), "expected dir, but got " + target_abspath
         self.packos = PackOS(self.path)
         self.mkppath = os.path.abspath(self.packos.sureDir(self.MKBUFNAME))
@@ -202,8 +204,15 @@ class MKPluginManager():
         if state == STATE_READY: return True
         return False
 
-    def add(self, path:str):
-        plugin = MKPlug(self, path)
+    def add(self, path:str, encoding:str=None):
+        """
+
+        :param path:
+        :param encoding: 用于指示解析文件时所用的格式
+                _: None
+        :return:
+        """
+        plugin = MKPlug(self, path, encoding if encoding else self.encoding)
         self.plugs[plugin.mname] = plugin
         self.info[plugin.mname] = plugin.info
         self.save(self.MKINFONAME)
