@@ -11,10 +11,10 @@ class PyFile:
         # 安全性检查
         bp = BiasPath(root, "")
         dp = BiasPath(file_path, "")
-        assert bp.isdir(),  "target path must be a dir, not : "     + str(bp)
-        assert bp.isabs(),  "target path must be a abspath, not : " + str(bp)
-        assert dp.isfile(), "target path must be a file, not : "    + str(dp)
-        assert dp.isabs(),  "target path must be a abspath, not : " + str(dp)
+        assert bp.isdir(), "target path must be a dir, not : " + str(bp)
+        assert bp.isabs(), "target path must be a abspath, not : " + str(bp)
+        assert dp.isfile(), "target path must be a file, not : " + str(dp)
+        assert dp.isabs(), "target path must be a abspath, not : " + str(dp)
         assert str(dp)[-3:].lower() == '.py', "target path must be a pyfile, not : " + str(dp)
 
         # 初始化
@@ -48,7 +48,6 @@ class PyFile:
         except UnicodeDecodeError as err:
             raise Exception(f"Unicode Error: <file:{self._raw_fpath}>\n{err}")
 
-
     def __str__(self):
         rels = "-"
         for rel in self.rel:
@@ -64,9 +63,9 @@ class ImportSegment:
     ORDA = ord('A')
     ORDZ = ord('Z')
     FROMPATTERN = '[^\n\s:]*from[\s\w.]*import.+\n'  # --*--
-    IMPPATTERN  = '[^\n\s:]*import.+\n'             # --*--
+    IMPPATTERN = '[^\n\s:]*import.+\n'  # --*--
     FKEYNAME = "$<restruct>:"
-    FKEYPATTERN = rf'\{FKEYNAME}\d+'                  # --*--
+    FKEYPATTERN = rf'\{FKEYNAME}\d+'  # --*--
 
     # --*--
     _from_replaces, _from_id = {}, 0
@@ -83,6 +82,7 @@ class ImportSegment:
     @property
     def _frep(self):
         return ImportSegment._from_replaces
+
     # --*-- /
 
     def __init__(self, segment: str, preix: str):
@@ -137,9 +137,9 @@ class ImportSegment:
         :return:
         """
         # print("dict:", ImportSegment._from_replaces)
-        seg   = match.group()
+        seg = match.group()
         index = seg.find(':')
-        _id   = seg[index + 1:]
+        _id = seg[index + 1:]
         if _id.isdigit():
             value = ImportSegment._from_replaces.get(_id)
             if value:
@@ -147,7 +147,6 @@ class ImportSegment:
         print(f"failed to import with {seg}")
         return f"raise ImportError('Failed to import from raw key: {seg}')"
 
-
     @property
     def prestr(self):
         if hasattr(self, '_prestr'): return self._prestr
@@ -230,10 +229,10 @@ class ImportSegment:
                 if piece.find('*') != -1:
                     right += f"{piece}, "
                     continue
-                match  = re.search('\sas\s', piece)
-                index  = match.span()[0] if match else len(piece) + 1
+                match = re.search('\sas\s', piece)
+                index = match.span()[0] if match else len(piece) + 1
                 module = re.sub('\s', '', piece[:index])
-                _new_  = self.newName(module, self.pre)
+                _new_ = self.newName(module, self.pre)
                 right += f"{_new_} {piece[index:]}, "
                 # import 本地库 没有as是非常危险的
                 if _new_ != module and match is None:
@@ -249,6 +248,7 @@ class ResourceSegment:
 
     """
     RESPATTERN = 'rf?[\"\'].+[\"\']'
+
     def __init__(self, segment: str, preix: str):
         self.seg = segment
         self.pre = preix
@@ -284,15 +284,31 @@ class ResourceSegment:
         ret = f"{self.seg[:index]}{self.pre}{self.seg[index:]}"
         return ret
 
-def resub(pat, rep_fn, txt):
-    while 1:
-        new = re.sub(pat, rep_fn, txt, 1)
-        if new == txt:
-            return new
-        else:
-            txt = new
 
-def PyRestruct(mod_path: str, new_path: str, run_path:str=None, encoding:str='utf-8', debug=False):
+def removeLongInterpret(pycode):
+    pycode = '\n' + pycode
+    pycode = re.sub('\n\s*[\"\'][\"\'][\"\']', '\n\"\"\"', pycode)
+    # 去除"""
+    index = pycode.find('"""')
+    while index != -1 and not (index != 0 and pycode[index - 1] != '\n'):  # 对于a = ”“”“”“这种不做处理
+        next = pycode[index + 3:].find('"""')
+        if next == -1:
+            raise Exception('""" does not closed. at:\n\n' + pycode[index - 100:index + 100] + "...")
+        pycode = pycode[:index] + '\n' + pycode[index + next + 6:]
+        index = pycode.find('"""')
+
+    # 去除'''
+    index = pycode.find("'''")
+    while index != -1 and not (index != 0 and pycode[index - 1] != '\n'):
+        next = pycode[index + 3:].find("'''")
+        if next == -1:
+            raise Exception("''' does not closed. at:\n\n" + pycode[index - 100:index + 100] + "...")
+        pycode = pycode[:index] + '\n' + pycode[index + next + 6:]
+        index = pycode.find("'''")
+    return pycode
+
+
+def PyRestruct(mod_path: str, new_path: str, run_path: str = None, encoding: str = 'utf-8', debug=False):
     """
     python代码(关于import路径和资源路径)的重构
     将目标mod移动到当前目录下的
@@ -308,15 +324,15 @@ def PyRestruct(mod_path: str, new_path: str, run_path:str=None, encoding:str='ut
     run_path = os.getcwd() if run_path is None else run_path
 
     # 检索目录是否正常
-    assert os.path.exists(run_path) , "run_path must be a exist path. Path: "       + run_path
-    assert os.path.isabs(run_path)  , "run_path must be a abspath. not "            + run_path
-    assert os.path.isdir(run_path)  , "run_path must be a dirpath. not "            + run_path
-    assert os.path.exists(mod_path) , "mod_path must be a exist path. Path: "       + mod_path
-    assert os.path.isabs(mod_path)  , "mod_path must be a abspath. not "            + mod_path
-    assert os.path.isdir(mod_path)  , "mod_path must be a dirpath. not "            + mod_path
-    assert os.path.exists(new_path) , "new mod_path must be a exist path. Path: "   + new_path
-    assert os.path.isabs(new_path)  , "new mod_path must be a abspath. not "        + new_path
-    assert os.path.isdir(new_path)  , "new mod_path must be a dirpath. not "        + new_path
+    assert os.path.exists(run_path), "run_path must be a exist path. Path: " + run_path
+    assert os.path.isabs(run_path), "run_path must be a abspath. not " + run_path
+    assert os.path.isdir(run_path), "run_path must be a dirpath. not " + run_path
+    assert os.path.exists(mod_path), "mod_path must be a exist path. Path: " + mod_path
+    assert os.path.isabs(mod_path), "mod_path must be a abspath. not " + mod_path
+    assert os.path.isdir(mod_path), "mod_path must be a dirpath. not " + mod_path
+    assert os.path.exists(new_path), "new mod_path must be a exist path. Path: " + new_path
+    assert os.path.isabs(new_path), "new mod_path must be a abspath. not " + new_path
+    assert os.path.isdir(new_path), "new mod_path must be a dirpath. not " + new_path
 
     # 预处理
     rel = os.path.relpath(new_path, run_path)  # 新目录相对运行目录的路径
@@ -334,13 +350,15 @@ def PyRestruct(mod_path: str, new_path: str, run_path:str=None, encoding:str='ut
                 path = os.path.join(root, file)
                 pyfiles += [PyFile(new_path, path, encoding)]
 
-
     # restruct body
     sys.path.remove(os.getcwd())
     ImportSegment.release()
     for py in pyfiles:
         pycode = py.read()
         pycode = pycode.replace('\n', '\n\n')  # 稀疏化
+        pycode = re.sub('#.*\n', '\n', pycode)  # 去注释#
+        pycode = removeLongInterpret(pycode)  # 去注释""" """
+        pycode = re.sub(ImportSegment.FROMPATTERN, lambda match: ImportSegment.replace(match, imp_pre), pycode)     # from import segment
         pycode = re.sub(ImportSegment.FROMPATTERN, lambda match: ImportSegment.replace(match, imp_pre), pycode)     # from import segment
         pycode = re.sub(ImportSegment.IMPPATTERN, lambda match: ImportSegment.replace(match, imp_pre), pycode)      # import segment
         pycode = re.sub(ImportSegment.FKEYPATTERN, ImportSegment.secReplace, pycode)                                # $<restruct> segment
